@@ -34,11 +34,15 @@
 #include <QApplication>
 #endif
 
+#ifdef Q_OS_ANDROID
+Q_DECL_EXPORT
+#endif
+
 int main(int argc, char *argv[])
 {
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     QApplication app(argc, argv);
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
@@ -61,6 +65,7 @@ int main(int argc, char *argv[])
                      applicationDescription,
                      KAboutLicense::LGPL_V2_1,
                      i18n("© 2020 KDE Community"));
+    about.setProgramLogo(QVariant(QIcon(QStringLiteral(":/org.kde.telly-skout.svg"))));
     about.addAuthor(QStringLiteral("Plata"), QString(), QStringLiteral("plata.hill@kdemail.net"));
     KAboutData::setApplicationData(about);
 
@@ -107,8 +112,6 @@ int main(int argc, char *argv[])
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
-    engine.rootContext()->setContextProperty(QStringLiteral("_settings"), TellySkoutSettings::self());
-
     QObject::connect(&app, &QCoreApplication::aboutToQuit, TellySkoutSettings::self(), &TellySkoutSettings::save);
 
     engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
